// +-------------------------------- DISCLAIMER ---------------------------------+
// |                                                                             |
// | This application program is provided to you free of charge as an example.   |
// | Despite the considerable efforts of Euresys personnel to create a usable    |
// | example, you should not assume that this program is error-free or suitable  |
// | for any purpose whatsoever.                                                 |
// |                                                                             |
// | EURESYS does not give any representation, warranty or undertaking that this |
// | program is free of any defect or error or suitable for any purpose. EURESYS |
// | shall not be liable, in contract, in torts or otherwise, for any damages,   |
// | loss, costs, expenses or other claims for compensation, including those     |
// | asserted by third parties, arising out of or in connection with the use of  |
// | this program.                                                               |
// |                                                                             |
// +-----------------------------------------------------------------------------+
//
// ImageProcessing.h: interface for the ImageProcessing class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_IMAGEPROCESSING_H__16ABAD2B_E644_4139_95FB_E7A71FA92E23__INCLUDED_)
#define AFX_IMAGEPROCESSING_H__16ABAD2B_E644_4139_95FB_E7A71FA92E23__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "Open_eVision_1_2.h"

/// Open eVision Namespace
using namespace Euresys::Open_eVision_1_2;


class ImageProcessing  
{


private:
	/// Source and temporary images
	EImageBW8 m_SrcImg;
	EImageBW8 m_ImgProcess;

	/// Source and temporary masks
	EImageBW8 m_MaskImg;
	EImageBW8 m_MaskProcess;

	/// ROI to analyze one test tube at a time
	EROIBW8 m_SrcROI;
	EROIBW8 m_MaskROI;

	/// EasyGauge tools to register the mask
	EWorldShape m_WorldShape;
	ELineGauge* p_LineGauge ;
	EPointGauge* p_PointGauge;

	/// EasyObject tools to detect reactions
	ECodedImage2 m_CodedImage[4];
	EImageEncoder m_Encoder;
	EObjectSelection m_Selection[4];

	/// Canny Edge detector tool to detect bubbles
	ECannyEdgeDetector m_CannyEdge;

	/// Reference offset and rotation values
	float m_ReferenceAngle;
	float m_ReferencePositionX;
	float m_ReferencePositionY;


public:
	void Draw(HDC _mContext);
	void Inspect(LPCTSTR _mFilename);
	void Initialize();
	
	ImageProcessing();
	virtual ~ImageProcessing();

};

#endif // !defined(AFX_IMAGEPROCESSING_H__16ABAD2B_E644_4139_95FB_E7A71FA92E23__INCLUDED_)
